| Title: | An R Package for D. H. Lawrence's Novels |
|---|---|
| Description: | This package provides access to the full texts of 6 of D. H. Lawrence's novels. |
| Authors: | Matthew Henderson |
| Maintainer: | Matthew Henderson <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.1 |
| Built: | 2026-05-21 07:57:52 UTC |
| Source: | https://github.com/MHenderson/dhlawrencer |
A dataset containing the text of D. H. Lawrence's 1922 novel "Aaron's Rod". The UTF-8 plain text was sourced from Project Gutenberg and is divided into elements of up to about 70 characters each. (Some elements are blank.)
aaronsrodaaronsrod
A character vector with 13402 elements
http://www.gutenberg.org/ebooks/4520
This package contains the complete text of D. H. Lawrence's novels.
Returns a tidy data frame of 6 of D. H. Lawrence's completed, published novels with
two columns: text, which contains the text of the novels divided into
elements of up to about 70 characters each, and book, which contains the titles of
the novels as a factor in order of publication.
lawrence_books()lawrence_books()
A data frame with two columns: text and book
library(dplyr) lawrence_books() %>% group_by(book) %>% summarise(total_lines = n())library(dplyr) lawrence_books() %>% group_by(book) %>% summarise(total_lines = n())
A dataset containing the text of D. H. Lawrence's 1920 novel "The Lost Girl". The UTF-8 plain text was sourced from Project Gutenberg and is divided into elements of up to about 70 characters each. (Some elements are blank.)
lostgirllostgirl
A character vector with 15742 elements
http://www.gutenberg.org/ebooks/23727
A dataset containing the text of D. H. Lawrence's 1911 novel "The White Peacock". The UTF-8 plain text was sourced from Project Gutenberg and is divided into elements of up to about 70 characters each. (Some elements are blank.)
peacockpeacock
A character vector with 14626 elements
http://www.gutenberg.org/ebooks/38561
A dataset containing the text of D. H. Lawrence's 1915 novel "The Rainbow". The UTF-8 plain text was sourced from Project Gutenberg and is divided into elements of up to about 70 characters each. (Some elements are blank.)
rainbowrainbow
A character vector with 20962 elements
http://www.gutenberg.org/ebooks/28948
A dataset containing the text of D. H. Lawrence's novel "Sons and Lovers" published in 1913. The UTF-8 plain text was sourced from Project Gutenberg and is divided into elements of up to about 70 characters each. (Some elements are blank.)
sonsandloverssonsandlovers
A character vector with 18214 elements
http://www.gutenberg.org/ebooks/217
A dataset containing the text of D. H. Lawrence's novel "Women in Love", published in 1920. The UTF-8 plain text was sourced from Project Gutenberg and is divided into elements of up to about 70 characters each. (Some elements are blank.)
womeninlovewomeninlove
A character vector with 20157 elements
http://www.gutenberg.org/ebooks/4240